interface Query {
    sessiontoken: string;
    offset: number;
    location: string;
    radius: number;
    language: string;
    types: string;
    components: string;
    strictbounds: boolean;
}
interface Options {
    key: string;
    query: Query;
}
interface MSubstring {
    length: number;
    offset: number;
}
declare type MSubstrings = Array<MSubstring>;
interface SFormat {
    main_text: string;
    main_text_matched_substrings: MSubstrings;
    secondary_text: string;
}
declare type SFormatting = Array<SFormat>;
interface Term {
    offset: number;
    value: string;
}
declare type Terms = Array<Term>;
interface Result {
    id: string;
    place_id: string;
    reference: string;
    description: string;
    matched_substrings: MSubstring;
    structured_formatting: SFormatting;
    terms: Terms;
    types: Array<string>;
}
declare type Results = Array<Result>;
interface GResponse extends Response {
    predictions: Results;
}
/** Class containing methods to get results from Google Places */
export default class GPlaces {
    options: Options;
    /**
     * Create an instance of the GPlaces class.
     * @param {Options} options
     *        Options for creating the handler
     */
    constructor(options: Options);
    /**
     * Make a request expecting a JSON response
     * @param {string} url
     *        Request URL for Google Maps
     * @private
     */
    request: (url?: string) => Promise<GResponse>;
    /**
     * Search for places matching input
     * @param {string} input
     *        Input string for the search
     * @returns {Promise<Results>}
     *          Returns an unaltered array of results from the Google Places API
     */
    search: (input?: string) => Promise<Result[]>;
    /**
     * Search for places matching input
     * @param {string} input
     *        Input string for the search
     * @param {number} radius
     *        Radius in meters to look for places
     * @returns {Promise<Results>}
     *          Returns an unaltered array of results from the Google Places API
     */
    searchNearby: (input?: string, radius?: number) => Promise<Result[]>;
}
export {};
